<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Bruno Gemelli <bruno.gemelli@e-smart.com.br>
 */
class BSeller_SkyHub_Model_Cron_Shipment_Plp_Clean extends BSeller_SkyHub_Model_Cron_Abstract
{
    public function execute(Mage_Cron_Model_Schedule $schedule)
    {
        $this->processStoreIteration($this, 'clearExpiredItems', $schedule);
    }

    /**
     * @param Mage_Cron_Model_Schedule $schedule
     */
    public function clearExpiredItems(Mage_Cron_Model_Schedule $schedule)
    {
        /** @var BSeller_SkyHub_Model_Integrator_Shipment_Plp $integrator */
        $integrator     = $this->shipmentPlpIntegrator();

        /** @var array $skyhubItems */
        $skyhubItems    = $integrator->plps();
        $today          = date('Y-m-d');

        foreach ($skyhubItems as $skyhubItem) {

            $id             = $this->arrayExtract($skyhubItem, 'id');
            $expirationDate = $this->arrayExtract($skyhubItem, 'expiration_date');

            //compare expiration_date - if valid, continue
            if (strtotime($expirationDate) < strtotime($today)) {
                continue;
            }

            /** @var BSeller_SkyHub_Model_Shipment_Plp $plp */
            $plp = Mage::getModel('bseller_skyhub/shipment_plp');
            $plp->load((int) $id, 'skyhub_code');

            //verify if PLP exists in magento - if not exists, continue
            if (!($plp instanceof Varien_Object) || !$plp->getId()) {
                continue;
            }

            try {
                $skyhubResult = $integrator->ungroup($plp->getSkyhubCode());

                //skip delete in magento if PLP was not ungrouped in SkyHub
                if (!$skyhubResult) {
                    continue;
                }

                $plp->delete();
            } catch (Mage_Exception $exception) {
                Mage::logException($exception);
            }
        }
    }
}