<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 * @author    Julio Reis <julio.reis@e-smart.com.br>
 */

trait BSeller_SkyHub_Model_Integrator_Catalog_Product_Validation
{

    use BSeller_SkyHub_Trait_Catalog_Product;
    use BSeller_SkyHub_Trait_Attribute_Notification;

    /**
     * @param BSeller_SkyHub_Model_Catalog_Product $product
     * @param bool                       $bypassVisibleCheck
     *
     * @return bool
     */
    public function canIntegrateProduct(Mage_Catalog_Model_Product $product,
                                        $bypassVisibleCheck = false,
                                        Mage_Core_Model_Store $store = null
    )
    {
    
        /**
         * If the notification block can be shown, it means there's a products attributes mapping problem.
         */
        if ($this->hasPendingAttributesToMap()) {
            return false;
        }

        $allowedTypes = array(
            Mage_Catalog_Model_Product_Type::TYPE_SIMPLE,
            Mage_Catalog_Model_Product_Type::TYPE_CONFIGURABLE,
        );

        if (!in_array($product->getTypeId(), $allowedTypes)) {
            return false;
        }

        //check if the product is flagged to doesn't go to marketplace
        if ($product->getIgnoreMarketplace()) {
            return false;
        }

        if (!$product->getId()) {
            return false;
        }

        if (!$product->getSku()) {
            return false;
        }

        if (!$product->hasData('visibility')) {
            $visibility = $product->getResource()
                ->getAttributeRawValue($product->getId(), 'visibility', $product->getStore());

            $product->setData('visibility', $visibility);
        }

        if (!$bypassVisibleCheck && !$this->hasAllowedVisibility($product)) {
            return false;
        }

        //check if every website atatched to this product is
        if ($store) {
            if (!in_array($store->getWebsiteId(), $product->getWebsiteIds())) {
                return false;
            }
        }
        //end

        return true;
    }
    
}
