<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */
class BSeller_SkyHub_Model_Observer_Sales_Order_Item extends BSeller_SkyHub_Model_Observer_Sales_Abstract
{
    
    /**
     * This method is responsible for overriding the product original price for configurable products.
     *
     * @param Varien_Event_Observer $observer
     */
    public function overrideProductOriginalPrice(Varien_Event_Observer $observer)
    {
        /**
         * @var Mage_Catalog_Model_Product  $product
         * @var Mage_Sales_Model_Quote_Item $quoteItem
         */
        $product   = $observer->getData('product');
        $quoteItem = $observer->getData('quote_item');
        
        if (!$this->validateProduct($product) || !$quoteItem) {
            return;
        }
    
        /**
         * @var array $config
         * @see BSeller_SkyHub_Model_Catalog_Product_Type_Common::_prepareProduct()
         */
        $config = (array) $product->getData('product_config');
        
        if (!$this->validateProductConfig($config)) {
            return;
        }
        
        $prices = array(
            'price'         => $this->arrayExtract($config, 'price'),
            'special_price' => $this->arrayExtract($config, 'special_price'),
            'final_price'   => $this->arrayExtract($config, 'final_price'),
        );
        
        $product->addData($prices);
    }
    
    
    /**
     * @param BSeller_SkyHub_Model_Catalog_Product $product
     *
     * @return bool
     */
    protected function validateProduct($product)
    {
        if (!$product) {
            return false;
        }
        
        if (!$product->getId()) {
            return false;
        }
        
        return true;
    }
    
    
    /**
     * @param array $config
     *
     * @return bool
     */
    protected function validateProductConfig(array $config)
    {
        if (empty($config)) {
            return false;
        }
        
        if (!isset($config['price'])) {
            return false;
        }
        
        if (!isset($config['special_price'])) {
            return false;
        }
        
        if (!isset($config['final_price'])) {
            return false;
        }
        
        return true;
    }
}
