<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */

class BSeller_SkyHub_Model_Resource_Sales_Order extends Mage_Sales_Model_Resource_Order
{
    
    /**
     * @param string $incrementId
     *
     * @return string
     */
    public function getEntityIdByIncrementId($incrementId)
    {
        /** @var Varien_Db_Select $select */
        $select = $this->_getReadAdapter()
            ->select()
            ->from($this->getMainTable(), 'entity_id')
            ->where('increment_id = ?', $incrementId)
            ->limit(1);
        
        return $this->_getReadAdapter()->fetchOne($select);
    }

    /**
     * @param $code
     * @return string
     */
    public function getEntityIdBySkyhubCode($code)
    {
        /** @var Varien_Db_Select $select */
        $select = $this->_getReadAdapter()
            ->select()
            ->from($this->getMainTable(), 'entity_id')
            ->where('bseller_skyhub_code = ?', $code)
            ->limit(1);

        return $this->_getReadAdapter()->fetchOne($select);
    }

    /**
     * @param $code
     * @return bool|string
     */
    public function getEntityIdByBizzCommerceSkyhubCode($code)
    {
        if (!$this->hasBizzCommerceSkyhubCodeColumn()) {
            return false;
        }

        /** @var Varien_Db_Select $select */
        $select = $this->_getReadAdapter()
            ->select()
            ->from($this->getMainTable(), 'entity_id')
            ->where('skyhub_code = ?', $code)
            ->limit(1);

        return $this->_getReadAdapter()->fetchOne($select);
    }

    /**
     * @param $orderId
     * @return string
     */
    public function getSkyhubCodeByOrderId($orderId)
    {
        /** @var Varien_Db_Select $select */
        $select = $this->_getReadAdapter()
            ->select()
            ->from($this->getMainTable(), 'bseller_skyhub_code')
            ->where('entity_id = ?', $orderId)
            ->limit(1);

        return $this->_getReadAdapter()->fetchOne($select);
    }

    /**
     * @param $orderId
     * @return string
     */
    public function getBizzCommerceSkyhubCodeByOrderId($orderId)
    {
        if (!$this->hasBizzCommerceSkyhubCodeColumn()) {
            return false;
        }

        $select = $this->_getReadAdapter()
            ->select()
            ->from($this->getMainTable(), 'skyhub_code')
            ->where('entity_id = ?', $orderId)
            ->limit(1);

        return $this->_getReadAdapter()->fetchOne($select);
    }

    /**
     * @return bool
     */
    protected function hasBizzCommerceSkyhubCodeColumn()
    {
        $readAdapter = $this->_getReadAdapter();
        if ($readAdapter->tableColumnExists($this->getMainTable(), 'skyhub_code')) {
            return true;
        }
        return false;
    }
}
