<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */

class BSeller_SkyHub_Model_Resource_Setup_Customer_Mapping extends BSeller_SkyHub_Model_Resource_Setup
{
    
    use BSeller_SkyHub_Trait_Customer_Attribute;

    /**
     * @return $this
     */
    public function installCustomerSkyHubRequiredAttributes()
    {
        $attributes = (array)  $this->getSkyHubFixedAttributes();
        $table = (string)$this->getTable('bseller_skyhub/customer_attributes_mapping');


        $defaultDataType  = BSeller_SkyHub_Model_Catalog_Product_Attributes_Mapping::DATA_TYPE_STRING;

        /** @var array $attribute */
        foreach ($attributes as $identifier => $data) {
            $skyhubCode  = $this->arrayExtract($data, 'code');
            $label       = $this->arrayExtract($data, 'label');
            $castType    = $this->arrayExtract($data, 'cast_type', $defaultDataType);
            $description = $this->arrayExtract($data, 'description');
            $validation  = $this->arrayExtract($data, 'validation');
            $enabled     = (bool) $this->arrayExtract($data, 'required', true);
            $required    = (bool) $this->arrayExtract($data, 'required', true);
            $editable    = (bool) $this->arrayExtract($data, 'editable', true);
            $hasOptions  = (bool) $this->arrayExtract($data, 'has_options', false);

            if (empty($skyhubCode) || empty($castType)) {
                continue;
            }
            
            $attributeData = array(
                'skyhub_code'        => $skyhubCode,
                'skyhub_label'       => $label,
                'skyhub_description' => $description,
                'enabled'            => $enabled,
                'cast_type'          => $castType,
                'validation'         => $validation,
                'required'           => $required,
                'editable'           => $editable,
                'has_options'        => $hasOptions
            );

            $installConfig = (array) $this->arrayExtract($data, 'attribute_install_config', array());
            $magentoCode   = $this->arrayExtract($installConfig, 'attribute_code');

            /** @var Mage_Eav_Model_Entity_Attribute $attribute */
            if ($attribute = $this->getAttributeByCode($magentoCode)) {
                $attributeData['attribute_id'] = $attribute->getId();
            }
            
            $this->getConnection()->beginTransaction();
            
            try {
                /** @var Varien_Db_Select $select */
                $select = $this->getConnection()
                               ->select()
                               ->from($table, 'id')
                               ->where('skyhub_code = :skyhub_code')
                               ->limit(1);
    
                $id = $this->getConnection()->fetchOne($select, array(':skyhub_code' => $skyhubCode));
    
                if ($id) {
                    $this->getConnection()->update($table, $attributeData, "id = {$id}");
                    $this->getConnection()->commit();
                    continue;
                }
    
                $this->getConnection()->insert($table, $attributeData);
                /*
                 * get the last attribute mapping table ID
                 */
                $parentAttributeId = $this->getConnection()->lastInsertId($table);
                $this->getConnection()->commit();

                /*
                 * if the attribute has options
                 */
                if (isset($attributeData['has_options']) && $attributeData['has_options']) {
                    $this->fillOptionsTable($this->arrayExtract($data, 'options', false), $parentAttributeId);
                }
            } catch (Exception $e) {
                $this->getConnection()->rollBack();
            }
        }
        
        return $this;
    }

    /**
     * @param $options
     *
     * @return void
     */
    private function fillOptionsTable($options, $parentAttributeId)
    {
        /*
         * save the options with the last attribute mapping saved ID
         */
        $table = (string)$this->getTable('bseller_skyhub/customer_attributes_mapping_options');
        foreach ($options as $option) {
            try {
                $optionData =
                    array(
                        'skyhub_code' => $this->arrayExtract($option, 'skyhub_code'),
                        'skyhub_label' => $this->arrayExtract($option, 'skyhub_label'),
                        'customer_attributes_mapping_id' => $parentAttributeId
                    );
                $this->getConnection()->insert($table, $optionData);
                $this->getConnection()->commit();
            } catch (Exception $e) {
                $this->getConnection()->rollBack();
            }
        }
    }

    /**
     * @return array
     */
    public function getSkyHubFixedAttributes()
    {
        return Mage::getSingleton('bseller_skyhub/config_customer')->getSkyHubFixedAttributes();
    }
}
