<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */
class BSeller_SkyHub_Model_Sales_Quote_Address_Total_Discount extends Mage_Sales_Model_Quote_Address_Total_Abstract
{
    
    /**
     * @param Mage_Sales_Model_Quote_Address $address
     *
     * @return $this|Mage_Sales_Model_Quote_Address_Total_Abstract
     */
    public function collect(Mage_Sales_Model_Quote_Address $address)
    {
        parent::collect($address);
    
        $skyhubDiscount = (float) Mage::registry('bseller_skyhub_discount_amount');
        
        if (!$skyhubDiscount) {
            return $this;
        }

        //force use the default magento field for discount;
        $this->setCode('discount');
        
        $items = $this->_getAddressItems($address);
        
        if (!$items) {
            return $this;
        }
    
        $subtotal = $address->getSubtotal();
        
        if (!$subtotal) {
            return $this;
        }
        
        /** @var Mage_Sales_Model_Quote_Address_Item $item */
        foreach ($items as $item) {
            $factor = (float) ($item->getPrice()/$subtotal)*$item->getQty();
            $amount = (float) $skyhubDiscount * $factor;
            
            $existingDiscount     = $item->getDiscountAmount();
            $existingBaseDiscount = $item->getBaseDiscountAmount();
            
            $item->setDiscountAmount($existingDiscount + $amount);
            $item->setBaseDiscountAmount($existingBaseDiscount + $amount);
            $item->setDiscountPercent($factor);
        }
        
        $discount     = $address->getTotalAmount($this->getCode());
        $baseDiscount = $address->getBaseTotalAmount($this->getCode());
        
        $totalDiscount     = $discount     + ($skyhubDiscount * -1);
        $baseTotalDiscount = $baseDiscount + ($skyhubDiscount * -1);
        
        $this->_addAmount($totalDiscount);
        $this->_addBaseAmount($baseTotalDiscount);
        
        return $this;
    }
}
