<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */
class BSeller_SkyHub_Model_Sales_Quote_Address_Total_Interest extends Mage_Sales_Model_Quote_Address_Total_Abstract
{
    
    use BSeller_SkyHub_Trait_Data;
    
    
    /**
     * @param Mage_Sales_Model_Quote_Address $address
     *
     * @return $this|Mage_Sales_Model_Quote_Address_Total_Abstract
     */
    public function collect(Mage_Sales_Model_Quote_Address $address)
    {
        parent::collect($address);
    
        $skyhubInterest = Mage::registry('bseller_skyhub_interest');
        
        if (!$skyhubInterest) {
            return $this;
        }
        
        $items = $this->_getAddressItems($address);
        
        if (!$items) {
            return $this;
        }
        
        $address->getQuote()->setData('bseller_skyhub_interest', (float) $skyhubInterest);
        
        $this->_addAmount((float) $skyhubInterest);
        $this->_addBaseAmount((float) $skyhubInterest);
        
        return $this;
    }
    
    
    /**
     * @return string
     */
    public function getLabel()
    {
        return $this->__('BSeller Interest');
    }
    
    
    /**
     * Fetch (Retrieve data as array)
     *
     * @param Mage_Sales_Model_Quote_Address $address
     * @return array
     */
    public function fetch(Mage_Sales_Model_Quote_Address $address)
    {
        $amount = (float) $address->getQuote()->getData('bseller_skyhub_interest');
    
        if ($amount != 0) {
            $address->addTotal(array(
                'code'  => $this->getCode(),
                'title' => $this->getLabel(),
                'value' => $amount
            ));
        }
        
        return parent::fetch($address);
    }
}
