<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */

trait BSeller_SkyHub_Trait_Catalog_Product_Attribute
{
    
    /** @var Mage_Eav_Model_Resource_Entity_Attribute_Collection */
    protected $attributeCollection;
    
    /** @var array */
    protected $productAttributes   = array();
    
    /** @var array */
    protected $attributesWhitelist = array();
    
    /** @var array */
    protected $entityTypes         = array();
    
    /** @var Mage_Catalog_Model_Product */
    protected $product;
    
    
    /**
     * @param string $attributeCode
     *
     * @return bool
     */
    protected function getAttributeByCode($attributeCode)
    {
        $this->initProductAttributes();
        
        if (!isset($this->productAttributes[$attributeCode])) {
            return false;
        }
        
        return $this->productAttributes[$attributeCode];
    }
    
    
    /**
     * @param int $attributeId
     *
     * @return bool|Mage_Eav_Model_Entity_Attribute
     */
    protected function getAttributeById($attributeId)
    {
        $this->initProductAttributes();
        
        /** @var Mage_Eav_Model_Entity_Attribute $attribute */
        foreach ($this->productAttributes as $attribute) {
            if ($attributeId == $attribute->getId()) {
                return $attribute;
            }
        }
        
        return false;
    }
    
    
    /**
     * @return array
     */
    protected function getAllAttributeIds()
    {
        $attributeIds = array();
        
        /** @var Mage_Eav_Model_Entity_Attribute $attribute */
        foreach ($this->productAttributes as $attribute) {
            $attributeIds[$attribute->getId()] = $attribute;
        }
        
        return $attributeIds;
    }
    
    
    /**
     * @return array
     */
    protected function initProductAttributes()
    {
        if (!empty($this->productAttributes)) {
            return $this->productAttributes;
        }
        
        /** @var Mage_Eav_Model_Entity_Attribute $attribute */
        foreach ($this->getProductAttributesCollection() as $attribute) {
            $this->productAttributes[$attribute->getAttributeCode()] = $attribute;
        }
        
        return $this->productAttributes;
    }


    /**
     * @return Mage_Eav_Model_Resource_Entity_Attribute_Collection
     */
    protected function getProductAttributesCollection()
    {
        /** @var Mage_Eav_Model_Resource_Entity_Attribute_Collection $collection */
        $collection = Mage::getResourceModel('eav/entity_attribute_collection');
        $collection->setEntityTypeFilter($this->getEntityType(Mage_Catalog_Model_Product::ENTITY));

        return $collection;
    }


    /**
     * @return array
     */
    protected function getIntegrableProductAttributes()
    {
        $integrable = array();

        /** @var Mage_Eav_Model_Entity_Attribute $attribute */
        foreach ($this->getProductAttributesCollection() as $attribute) {
            if (!$this->validateAttributeForIntegration($attribute)) {
                continue;
            }

            $integrable[$attribute->getId()] = $attribute;
        }

        return $integrable;
    }


    /**
     * @param array $ids
     * @param array $excludeIds
     *
     * @return array
     */
    protected function getProductAttributes(array $ids = array(), array $excludeIds = array())
    {
        $this->initProductAttributes();
        
        $attributes = array();
        
        /**
         * @var string                          $code
         * @var Mage_Eav_Model_Entity_Attribute $attribute
         */
        foreach ($this->productAttributes as $code => $attribute) {
            if (!empty($ids) && !in_array($attribute->getId(), $ids)) {
                continue;
            }
            
            if (!empty($excludeIds) && in_array($attribute->getId(), $excludeIds)) {
                continue;
            }
            
            $attributes[$code] = $attribute;
        }
        
        return $attributes;
    }
    
    
    /**
     * @param string $code
     *
     * @return Mage_Eav_Model_Entity_Type
     */
    protected function getEntityType($code)
    {
        if (isset($this->entityTypes[$code])) {
            return $this->entityTypes[$code];
        }
        
        /** @var Mage_Eav_Model_Entity_Type $type */
        $type = Mage::getModel('eav/entity_type');
        $type->loadByCode($code);
        
        $this->entityTypes[$code] = $type;
        
        return $type;
    }
    
    
    /**
     * @return array
     */
    protected function getProductAttributeBlacklist()
    {
        /** @var BSeller_SkyHub_Model_Config $config */
        $config = Mage::getSingleton('bseller_skyhub/config_catalog_product');
        return $config->getBlacklistedAttributes();
    }
    
    
    /**
     * @param string $attributeCode
     *
     * @return bool
     */
    protected function isAttributeCodeInBlacklist($attributeCode)
    {
        /** @var BSeller_SkyHub_Model_Config $config */
        $config = Mage::getSingleton('bseller_skyhub/config_catalog_product');
        return $config->isAttributeCodeInBlacklist($attributeCode);
    }


    /**
     * @param string $code
     * @param array  $attributeData
     *
     * @return Mage_Eav_Model_Entity_Attribute
     *
     * @throws Mage_Core_Exception
     */
    protected function createProductAttribute($code, array $attributeData)
    {
        $groupName = 'BSeller SkyHub';

        /** @var BSeller_SkyHub_Model_Resource_Eav_Entity_Attribute_Set $resource */
        $resource = Mage::getResourceModel('bseller_skyhub/eav_entity_attribute_set');
        $result   = $resource->setupEntityAttributeGroups(
            $this->getEntityType(Mage_Catalog_Model_Product::ENTITY)->getId(),
            $groupName
        );

        if (!$result) {
            Mage::throwException($this->__('The attribute group could not be created.'));
        }

        $attributeData['group'] = $groupName;

        /** @var Mage_Eav_Model_Entity_Setup $installer */
        $installer = Mage::getModel('eav/entity_setup', 'core_setup');
        $installer->startSetup();
        $installer->addAttribute(Mage_Catalog_Model_Product::ENTITY, $code, $attributeData);
        $installer->endSetup();

        return $this->loadProductAttribute($code);
    }


    /**
     * @param string $groupName
     *
     * @return $this
     */
    protected function initSkyHubAttributeGroup($groupName)
    {
        /** @var Mage_Eav_Model_Resource_Entity_Attribute_Set_Collection $setCollection */
        $setCollection = Mage::getResourceModel('eav/entity_attribute_set_collection');
        $setCollection->setEntityTypeFilter($this->getEntityType(Mage_Catalog_Model_Product::ENTITY)->getId());

        /** @var Mage_Eav_Model_Entity_Attribute_Set $attributeSet */
        foreach ($setCollection as $attributeSet) {
            try {
                /** @var Mage_Eav_Model_Entity_Attribute_Group $group */
                $group = Mage::getModel('eav/entity_attribute_group');
                $group->setAttributeSetId($attributeSet->getId())
                    ->setAttributeGroupName($groupName)
                    ->setSortOrder(900)
                ;

                $group->save();
            } catch (Exception $e) {
                Mage::logException($e);
            }
        }

        return $this;
    }


    /**
     * @param $code
     *
     * @return Mage_Eav_Model_Entity_Attribute
     *
     * @throws Mage_Core_Exception
     */
    protected function loadProductAttribute($code)
    {
        /** @var Mage_Eav_Model_Entity_Attribute $attribute */
        $attribute = Mage::getModel('eav/entity_attribute')->loadByCode(Mage_Catalog_Model_Product::ENTITY, $code);
        return $attribute;
    }


    /**
     * @param Mage_Eav_Model_Entity_Attribute $attribute
     *
     * @return bool
     */
    protected function validateAttributeForIntegration(Mage_Eav_Model_Entity_Attribute $attribute)
    {
        if (!$attribute->getStoreLabel()) {
            return false;
        }

        if ($this->isAttributeCodeInBlacklist($attribute->getAttributeCode())) {
            return false;
        }

        return true;
    }
}
