<?php
/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  BSeller
 * @package   BSeller_SkyHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br)
 *
 * @author    Julio Reis <julio.reis@e-smart.com.br>
 */
trait BSeller_SkyHub_Trait_Customer_Attribute_Mapping
{
    
    /** @var array */
    protected $mappedAttributes = array();
    
    
    /**
     * @param string $skyhubCode
     *
     * @return mixed|null
     */
    public function getMappedAttribute($skyhubCode)
    {
        $this->initMappedAttributes();
        
        if (isset($this->mappedAttributes[$skyhubCode])) {
            return $this->mappedAttributes[$skyhubCode];
        }
        
        return null;
    }
    
    
    /**
     * @return array
     */
    public function getMappedAttributes()
    {
        $this->initMappedAttributes();
        
        return (array) $this->mappedAttributes;
    }
    
    
    /**
     * @return $this
     */
    protected function initMappedAttributes()
    {
        if (empty($this->mappedAttributes)) {
            $this->mappedAttributes = array();
            
            /** @var BSeller_SkyHub_Model_Customer_Attributes_Mapping $mappedAttribute */
            foreach ($this->getMappedAttributesCollection() as $mappedAttribute) {
                $this->mappedAttributes[$mappedAttribute->getSkyhubCode()] = $mappedAttribute;
            }
        }
        
        return $this;
    }
    
    
    /**
     * @return BSeller_SkyHub_Model_Resource_Customer_Attributes_Mapping_Collection
     */
    public function getMappedAttributesCollection()
    {
        /** @var BSeller_SkyHub_Model_Resource_Customer_Attributes_Mapping_Collection $collection */
        $collection = Mage::getResourceModel('bseller_skyhub/customer_attributes_mapping_collection');
        $collection->setMappedAttributesFilter();
        
        return $collection;
    }

    /**
     * @param string $attributeMappingSkyhubCode
     * @param string $attributeOptionCode
     * @return string
     */
    public function getAttributeMappingOptionMagentoValue($attributeMappingSkyhubCode, $attributeOptionCode)
    {
        $customerMapping = Mage::getModel('bseller_skyhub/customer_attributes_mapping')->load($attributeMappingSkyhubCode, 'skyhub_code');
        return $customerMapping->getMagentoValueOption($attributeOptionCode);
    }
}
