<?php
/**
 * B2W Digital - Companhia Digital
 *
 * Do not edit this file if you want to update this SDK for future new versions.
 * For support please contact the e-mail bellow:
 *
 * sdk@e-smart.com.br
 *
 * @category  SkuHub
 * @package   SkuHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br).
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */

namespace SkyHub\Api\DataTransformer\Catalog\Product;

use SkyHub\Api\DataTransformer\Builders;
use SkyHub\Api\DataTransformer\DataTransformerAbstract;

class Create extends DataTransformerAbstract
{

    use Builders;


    /**
     * Attribute constructor.
     *
     * @param string $sku
     * @param array  $data
     * @param array  $images
     * @param array  $categories
     * @param array  $specifications
     * @param array  $variations
     * @param array  $variationAttributes
     */
    public function __construct(
        $sku,
        array $data = [],
        array $images = [],
        array $categories = [],
        array $specifications = [],
        array $variations = [],
        array $variationAttributes = []
    ) {
        $product = [
            'sku'               => (string) $sku,
            'name'              => (string) $this->arrayExtract($data, 'name', ''),
            'description'       => (string) $this->arrayExtract($data, 'description', ''),
            'status'            => (string) $this->arrayExtract($data, 'status', 'disabled'),
            'qty'               => (int)    $this->arrayExtract($data, 'qty', 0),
            'price'             => (float)  $this->arrayExtract($data, 'price', 0.0000),
            'promotional_price' =>          $this->arrayExtract($data, 'promotional_price', null),
            'cost'              => (float)  $this->arrayExtract($data, 'cost', 0.0000),
            'weight'            => (float)  $this->arrayExtract($data, 'weight', 0.0000),
            'height'            => (float)  $this->arrayExtract($data, 'height', 0.0000),
            'width'             => (float)  $this->arrayExtract($data, 'width', 0.0000),
            'length'            => (float)  $this->arrayExtract($data, 'length', 0.0000),
            'brand'             => (string) $this->arrayExtract($data, 'brand', ''),
            'ean'               => (string) $this->arrayExtract($data, 'ean', ''),
            'nbm'               => (string) $this->arrayExtract($data, 'nbm', ''),
        ];

        /** Setup images. */
        $this->buildProductImages($product, $images);

        /** Setup categories. */
        $this->buildProductCategories($product, $categories);

        /** Setup specifications. */
        $this->buildProductSpecifications($product, $specifications);

        /** Setup product variations. */
        foreach ($variations as $variation) {
            $_sku            = $this->arrayExtract($variation, 'sku', '');
            $_qty            = $this->arrayExtract($variation, 'qty', 0);
            $_ean            = $this->arrayExtract($variation, 'ean', '');
            $_images         = $this->arrayExtract($variation, 'images', []);
            $_specifications = $this->arrayExtract($variation, 'specifications', []);

            $this->buildProductVariation($product, $_sku, $_qty, $_ean, $_images, $_specifications);
        }

        /** Setup product variation attributes. */
        $this->buildProductVariationAttributes($product, $variationAttributes);

        $this->setOutputData([
            'product' => $product
        ]);

        parent::__construct();
    }


    /**
     * @return $this
     */
    protected function prepareOutput()
    {
        parent::prepareOutput();
        return $this;
    }
}
