<?php
/**
 * B2W Digital - Companhia Digital
 *
 * Do not edit this file if you want to update this SDK for future new versions.
 * For support please contact the e-mail bellow:
 *
 * sdk@e-smart.com.br
 *
 * @category  SkuHub
 * @package   SkuHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br).
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */

namespace SkyHub\Api\DataTransformer\Sales\Order;

use SkyHub\Api\DataTransformer\DataTransformerAbstract;

class Shipment extends DataTransformerAbstract
{

    /**
     * Shipment constructor.
     *
     * @param string $orderId
     * @param array $items
     * @param string $trackCode
     * @param string $trackCarrier
     * @param string $trackMethod
     * @param string $trackUrl
     * @param string $status
     */
    public function __construct($orderId, array $items, $trackCode, $trackCarrier, $trackMethod, $trackUrl, $status = null)
    {
        $shipment = [
            'shipment' => [
                'code'  => $orderId,
                'track' => [
                    'code'    => $trackCode,
                    'carrier' => $trackCarrier,
                    'method'  => $trackMethod,
                    'url'     => $trackUrl,
                ]
            ]
        ];

        if ($status) {
            $shipment['status'] = $status;
        }

        /** @var array $item */
        foreach ($items as $item) {
            $shipment['items'][] = [
                'sku' => $item['sku'],
                'qty' => $item['qty'],
            ];
        }

        $this->setOutputData($shipment);

        parent::__construct();
    }
}
