<?php

namespace SkyHub\Api\Handler\Request\Catalog\Product;

use SkyHub\Api\DataTransformer\Catalog\Product\Attribute\Create as CreateTransformer;
use SkyHub\Api\DataTransformer\Catalog\Product\Attribute\Update as UpdateTransformer;
use SkyHub\Api\EntityInterface\Catalog\Product\Attribute;
use SkyHub\Api\Handler\Request\HandlerAbstract;
use SkyHub\Api\Handler\Response\HandlerInterface;

/**
 * BSeller Platform | B2W - Companhia Digital
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  SkuHub
 * @package   SkuHub
 *
 * @copyright Copyright (c) 2018 B2W Digital - BSeller Platform. (http://www.bseller.com.br).
 *
 * @author    Tiago Sampaio <tiago.sampaio@e-smart.com.br>
 */
class AttributeHandler extends HandlerAbstract
{

    /** @var string */
    protected $baseUrlPath = '/attributes';


    /**
     * @param string $code
     * @param string $label
     * @param array  $options
     *
     * @return HandlerInterface
     */
    public function create($code, $label, array $options = [])
    {
        $transformer = new CreateTransformer($code, $label, $options);
        $body        = $transformer->output();

         /** @var HandlerInterface $responseHandler */
        $responseHandler = $this->service()->post($this->baseUrlPath(), $body);
        
        return $responseHandler;
    }
    
    
    /**
     * @param string $code
     * @param string $label
     * @param array  $options
     *
     * @return \SkyHub\Api\Handler\Response\HandlerInterface
     */
    public function update($code, $label, array $options = [])
    {
        $transformer = new UpdateTransformer($code, $label, $options);
        $body        = $transformer->output();
    
        /** @var HandlerInterface $responseHandler */
        $responseHandler = $this->service()->put($this->baseUrlPath($code), $body);
    
        return $responseHandler;
    }


    /**
     * @return Attribute
     */
    public function entityInterface()
    {
        return new Attribute($this);
    }
}
